@@ -6,6 +6,7 @@ class PlanStep:
     def __init__(self, step_num=None, references=None):
         self.step_num = step_num
         self.references = references or []
+        self.result_data = None
 
     @property
     def result(self):
@@ -18,6 +19,10 @@ class PlanStep:
             return False
 
         for k in vars(self):
+            # skip result comparison
+            if k == 'result_data':
+                continue
+
             if getattr(self, k) != getattr(other, k):
                 return False
 
@@ -28,6 +33,8 @@ class PlanStep:
         attrs_str = ', '.join([f'{k}={str(v)}' for k, v in attrs_dict.items()])
         return f'{self.__class__.__name__}({attrs_str})'
 
+    def set_result(self, result):
+        self.result_data = result
 
 class ProjectStep(PlanStep):
     """Selects columns from a dataframe"""
@@ -165,6 +172,14 @@ class GetPredictorColumns(PlanStep):
         self.predictor = predictor
 
 
+class GetTableColumns(PlanStep):
+    """Returns an empty dataframe of shape and columns like predictor results."""
+    def __init__(self, namespace, table, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.namespace = namespace
+        self.table = table
+
+
 class MapReduceStep(PlanStep):
     """Applies a step for each value in a list, and then reduces results to a single dataframe"""
     def __init__(self, values, step, reduce, *args, **kwargs):
